@@ -24,11 +24,14 @@ from .confidenceintervalelement import ConfidenceIntervalElement
 from .element import Element
 from .fixedpositionsizeelement import FixedPositionSizeElement
 from .fixedspreadelement import FixedSpreadElement
+from .maximumquantityelement import MaximumQuantityElement
+from .minimumquantityelement import MinimumQuantityElement
 from .minimumchargeelement import MinimumChargeElement
 from .preventpostonlycrossingbookelement import PreventPostOnlyCrossingBookElement
 from .quotesinglesideelement import QuoteSingleSideElement
 from .roundtolotsizeelement import RoundToLotSizeElement
 from .ratioselement import RatiosElement
+from .topofbookelement import TopOfBookElement
 
 _DEFAULT_CHAIN = [
     "confidenceinterval",
@@ -58,11 +61,14 @@ class ChainBuilder:
         ConfidenceIntervalElement.add_command_line_parameters(parser)
         FixedSpreadElement.add_command_line_parameters(parser)
         FixedPositionSizeElement.add_command_line_parameters(parser)
+        MaximumQuantityElement.add_command_line_parameters(parser)
+        MinimumQuantityElement.add_command_line_parameters(parser)
         MinimumChargeElement.add_command_line_parameters(parser)
         PreventPostOnlyCrossingBookElement.add_command_line_parameters(parser)
         QuoteSingleSideElement.add_command_line_parameters(parser)
         RatiosElement.add_command_line_parameters(parser)
         RoundToLotSizeElement.add_command_line_parameters(parser)
+        TopOfBookElement.add_command_line_parameters(parser)
 
     # This function is the converse of `add_command_line_parameters()` - it takes
     # an argument of parsed command-line parameters and expects to see the ones it added
@@ -98,8 +104,12 @@ class ChainBuilder:
             return FixedSpreadElement.from_command_line_parameters(args)
         elif proper_name == "FIXEDPOSITIONSIZE":
             return FixedPositionSizeElement.from_command_line_parameters(args)
+        elif proper_name == "MAXIMUMQUANTITY":
+            return MaximumQuantityElement.from_command_line_parameters(args)
         elif proper_name == "MINIMUMCHARGE":
             return MinimumChargeElement.from_command_line_parameters(args)
+        elif proper_name == "MINIMUMQUANTITY":
+            return MinimumQuantityElement.from_command_line_parameters(args)
         elif proper_name == "PREVENTPOSTONLYCROSSINGBOOK":
             return PreventPostOnlyCrossingBookElement.from_command_line_parameters(args)
         elif proper_name == "QUOTESINGLESIDE":
@@ -108,5 +118,7 @@ class ChainBuilder:
             return RatiosElement.from_command_line_parameters(args)
         elif proper_name == "ROUNDTOLOTSIZE":
             return RoundToLotSizeElement.from_command_line_parameters(args)
+        elif proper_name == "TOPOFBOOK":
+            return TopOfBookElement.from_command_line_parameters(args)
         else:
             raise Exception(f"Unknown chain element: '{proper_name}'")
