@@ -16,7 +16,7 @@
 import typing
 
 from decimal import Decimal
-from pyserum.market import Market as PySerumMarket
+from pyserum.market.market import Market as PySerumMarket
 from pyserum.market.orderbook import OrderBook as PySerumOrderBook
 from solana.publickey import PublicKey
 
@@ -36,8 +36,11 @@ from .token import Token
 # This class encapsulates our knowledge of a Serum spot market.
 #
 class SerumMarket(LoadedMarket):
-    def __init__(self, serum_program_address: PublicKey, address: PublicKey, base: Token, quote: Token, underlying_serum_market: PySerumMarket):
+    def __init__(self, serum_program_address: PublicKey, address: PublicKey, base: Token, quote: Token,
+                 underlying_serum_market: PySerumMarket) -> None:
         super().__init__(serum_program_address, address, InventorySource.SPL_TOKENS, base, quote, RaisingLotSizeConverter())
+        self.base: Token = base
+        self.quote: Token = quote
         self.underlying_serum_market: PySerumMarket = underlying_serum_market
         base_lot_size: Decimal = Decimal(underlying_serum_market.state.base_lot_size())
         quote_lot_size: Decimal = Decimal(underlying_serum_market.state.quote_lot_size())
@@ -82,8 +85,10 @@ class SerumMarket(LoadedMarket):
 # This class holds information to load a `SerumMarket` object but doesn't automatically load it.
 #
 class SerumMarketStub(Market):
-    def __init__(self, serum_program_address: PublicKey, address: PublicKey, base: Token, quote: Token):
+    def __init__(self, serum_program_address: PublicKey, address: PublicKey, base: Token, quote: Token) -> None:
         super().__init__(serum_program_address, address, InventorySource.SPL_TOKENS, base, quote, RaisingLotSizeConverter())
+        self.base: Token = base
+        self.quote: Token = quote
 
     def load(self, context: Context) -> SerumMarket:
         underlying_serum_market: PySerumMarket = PySerumMarket.load(
